/*@file             hal_spi.c
* @brief            the low level operation and configuration about SPI
* @author           hyh
* @date             2022.6.6
* @version          1.0
* @copyright        Chengdu Ebyte Electronic Technology Co.Ltd
**********************************************************************************
*/
#include "hal_spi.h"
/*!
================================================================================
------------------------------------Functions-----------------------------------
================================================================================
*/

/*!
 *  @brief        Initialize the SPI Configuration
 *  @note         EUSCI_B   SPI Rate:1MHz
*/
void hal_spi_init(void)
{
    //Initialize Master
    EUSCI_B_SPI_initMasterParam SpiCfgParam = {0};

    SpiCfgParam.selectClockSource = EUSCI_B_SPI_CLOCKSOURCE_SMCLK;
    SpiCfgParam.clockSourceFrequency = CS_getSMCLK();
    SpiCfgParam.desiredSpiClock = 1000000;
    SpiCfgParam.msbFirst = EUSCI_B_SPI_MSB_FIRST;
    SpiCfgParam.clockPhase = EUSCI_B_SPI_PHASE_DATA_CHANGED_ONFIRST_CAPTURED_ON_NEXT;
    SpiCfgParam.clockPolarity = EUSCI_B_SPI_CLOCKPOLARITY_INACTIVITY_HIGH;
    SpiCfgParam.spiMode = EUSCI_B_SPI_3PIN;
    EUSCI_B_SPI_initMaster(EUSCI_B0_BASE, &SpiCfgParam);
    EUSCI_B_SPI_enable(EUSCI_B0_BASE);
}
/*!
 *  @brief        Exchange byte via the SPI bus
 *  @note
*/
INT8U hal_spi_exchangebyte(INT8U w_data)
{
    INT8U r_data;
    //Transmit Data to slave
    EUSCI_B_SPI_transmitData(EUSCI_B0_BASE, w_data);
    while (!EUSCI_B_SPI_getInterruptStatus(EUSCI_B0_BASE,EUSCI_B_SPI_TRANSMIT_INTERRUPT));
    while (!EUSCI_B_SPI_getInterruptStatus(EUSCI_B0_BASE,EUSCI_B_SPI_RECEIVE_INTERRUPT));
    r_data = EUSCI_B_SPI_receiveData(EUSCI_B0_BASE);
    return r_data;
}
