/*@file             hal_uart.c
* @brief            the low level operation and configuration about UART
* @author           hyh
* @date             2022.6.6
* @version          1.0
* @copyright        Chengdu Ebyte Electronic Technology Co.Ltd
**********************************************************************************
*/
#include "app.h"
#include "hal_uart.h"

/*!
================================================================================
------------------------------------Functions-----------------------------------
================================================================================
*/
/*!
 *  @brief        Initialize the UART Configuration
 *  @note         EUSCI_A
*/
void hal_uart_init(void)
{
    EUSCI_A_UART_initParam UartCfgParam = {0};
    UartCfgParam.selectClockSource = EUSCI_A_UART_CLOCKSOURCE_SMCLK;

    UartCfgParam.clockPrescalar = 52;
    UartCfgParam.firstModReg = 1;
    UartCfgParam.secondModReg = 73;

    UartCfgParam.msborLsbFirst = EUSCI_A_UART_LSB_FIRST;
    UartCfgParam.numberofStopBits = EUSCI_A_UART_ONE_STOP_BIT;
    UartCfgParam.overSampling = EUSCI_A_UART_OVERSAMPLING_BAUDRATE_GENERATION;

    UartCfgParam.parity = EUSCI_A_UART_NO_PARITY;
    if(STATUS_FAIL == EUSCI_A_UART_init(EUSCI_A1_BASE,&UartCfgParam))
    {
        return;
    }
    EUSCI_A_UART_enable(EUSCI_A1_BASE);
    EUSCI_A_UART_clearInterrupt(EUSCI_A1_BASE,EUSCI_A_UART_TRANSMIT_COMPLETE_INTERRUPT);
    EUSCI_A_UART_clearInterrupt(EUSCI_A1_BASE,EUSCI_A_UART_RECEIVE_INTERRUPT);
    //Enable USCI_A0 RX & TX interrupt
    EUSCI_A_UART_enableInterrupt(EUSCI_A1_BASE,EUSCI_A_UART_TRANSMIT_COMPLETE_INTERRUPT);
    EUSCI_A_UART_enableInterrupt(EUSCI_A1_BASE,EUSCI_A_UART_RECEIVE_INTERRUPT);
}
/*!
 *  @brief        This is the USCI_A0 interrupt vector service routine.
 *  @note
*/
#if defined(__TI_COMPILER_VERSION__) || defined(__IAR_SYSTEMS_ICC__)
#pragma vector=USCI_A1_VECTOR
__interrupt
#elif defined(__GNUC__)
__attribute__((interrupt(USCI_A1_VECTOR)))
#endif
__interrupt void EUSCI_A1_ISR(void)
{
    switch(__even_in_range(UCA1IV,USCI_UART_UCTXCPTIFG))
    {
        case USCI_NONE:
            break;
        case USCI_UART_UCRXIFG:
            Uart_Rx_Interrupt_Cb();
            break;
        case USCI_UART_UCTXIFG:
            break;
        case USCI_UART_UCSTTIFG:
            break;
        case USCI_UART_UCTXCPTIFG:
            Uart_Tx_Interrupt_Cb();
            break;
    }
}
