/*@file  	        cc1101.c
* @brief            the External API for the CC1101
* @details          
* @author           hyh
* @date             2021.5.26
* @version          1.0
* @copyright        Chengdu Ebyte Electronic Technology Co.Ltd
**********************************************************************************
*/
#ifndef CC1101_H
#define CC1101_H

#include "bsp.h"
#include "cc1101_reg.h"
#include "MyTypeDef.h"

#define   CC_CSN_LOW()    GPIO_setOutputLowOnPin(CC1101_CSN_PORT,CC1101_CSN_PIN); while(GPIO_getInputPinValue(SPI_PORT,SPI_PIN_MISO) != 0);
#define   CC_CSN_HIGH()   GPIO_setOutputHighOnPin(CC1101_CSN_PORT,CC1101_CSN_PIN);
#define   CC_IRQ_READ()   GPIO_getInputPinValue(CC1101_GDO0_PORT,CC1101_GDO0_PIN)
#define   SPI_ExchangeByte(data)  hal_spi_exchangebyte(data)

/*Transmit mode*/
typedef enum { TX_MODE, RX_MODE } TRMODE;
/*Address check mode*/
typedef enum { BROAD_ALL, BROAD_NO, BROAD_0, BROAD_0AND255 } ADDR_MODE;
/*Tx data mode*/
typedef enum { BROADCAST, ADDRESS_CHECK} TX_DATA_MODE;

/*Device address*/
#define DEVICE_ADDRESS 0x05
/*@brief Radio register definition*/
typedef struct
{
  INT8U addr;        //The address of the register
  INT8U value;       //The value of the register
}CC1101_REG_DATA;

extern INT8U PaTable[8];
/*
================================================================================
-------------------------------------External APIs------------------------------
================================================================================
*/
/*Write a byte to the specified register */
void CC1101_WriteReg(INT8U addr,INT8U value);
/*Write bytes to the specified register */
void CC1101_WriteMultiReg(INT8U addr,INT8U *buffer,INT8U size);
/*Write Command to CC1101*/
void CC1101_WriteCmd(INT8U command);
/*Read a byte from the specified register*/
INT8U CC1101_ReadReg(INT8U addr);
/*Read bytes from the specified register continously*/
void CC1101_ReadMultiReg(INT8U addr,INT8U *buffer,INT8U size);
/*Read Current status from the status register*/
INT8U CC1101_ReadStatus(INT8U addr);
/*Reset the CC1101*/
void CC1101_Reset(void);
/*Set the address and address mode of the CC1101*/
void CC1101_SetAddress(INT8U address,ADDR_MODE AddressMode);
/*Set the sync byte*/
void CC1101_SetSync(INT16U sync);
/*Set the datarate*/
void CC1101_SetDataRate(INT8U datarate_index);
/*Set the Channel*/
void CC1101_SetChannel(INT8U channel);
/*Set the output power*/
void CC1101_SetPAPower(INT8U power_index);
/*Initialize the CC1101*/
void CC1101_Init(void);
/*Set the device as Tx mode or Rx mode*/
void CC1101_SetTRMode(TRMODE mode);
/*Set the CC1101 into the IDLE mode*/
void CC1101_SetIdle(void);
/*Flush the TX Buffer*/
void CC1101_ClrTxBuffer(void);
/*Flush the RX Buffer*/
void CC1101_ClrRxBuffer(void);
/*Get the recieve bytes count*/
INT8U CC1101_GetRxCnt(void);
/*Send data packet*/
void CC1101_SendPacket( INT8U *txbuffer, INT8U size, TX_DATA_MODE mode );
/*Recieve data packet*/
INT8U CC1101_RecievePacket(INT8U *rxbuffer);
#endif
